@@ -2,7 +2,8 @@
 //
 // RInside.h: R/C++ interface class library -- Easier R embedding into C++
 //
-// Copyright (C) 2009 - 2010 Dirk Eddelbuettel
+// Copyright (C) 2009        Dirk Eddelbuettel
+// Copyright (C) 2010        Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of RInside.
 //
@@ -23,15 +24,13 @@
 #include <vector>
 #include <iostream>
 
-#include <R.h>
+#include <Rcpp.h>
+
 #include <Rembedded.h>
-#include <Rversion.h>
-#include <Rdefines.h>
 #ifndef WIN32
 #define R_INTERFACE_PTRS
 #include <Rinterface.h>
 #endif
-#include <R_ext/Parse.h>
 #include <R_ext/RStartup.h>
 
 #include "MemBuf.h"
@@ -39,36 +38,43 @@
 class RInside {
 private:
     MemBuf mb_m;
-
+    Rcpp::Environment global_env ;
+    
     bool verbose_m;				// private switch
 
     void init_tempdir(void);
     void init_rand(void);
     void autoloads(void);
+    
+    void initialize(const int argc, const char* const argv[] ) ;
 
 public:
-    int parseEval(const std::string & line, SEXP &ans);
-    int parseEvalQ(const std::string & line);
-
-    void assign(const std::vector< std::vector< double > > & mat, const std::string & nam);
-    void assign(const std::vector< std::vector< int > > & mat, const std::string & nam);
-    void assign(const std::vector< std::string > & vec, const std::string & nam);
-    void assign(const std::vector< double > & vec, const std::string & nam);
-    void assign(const std::vector< int > & vec, const std::string & nam);
-    void assign(const std::string & txt, const std::string & nam);
+    int  parseEval(const std::string & line, SEXP &ans); // parse line, return in ans; error code rc
+    void parseEvalQ(const std::string & line);		 // parse line, no return (throws on error)
+    SEXP parseEval(const std::string & line);		 // parse line, return SEXP (throws on error)
 
+    template <typename T> 
+    void assign(const T& object, const std::string& nam) {
+	global_env.assign( nam, object ) ;
+    }
+    
+    RInside() ;
     RInside(const int argc, const char* const argv[]);
     ~RInside();
+    
+    Rcpp::Environment::Binding operator[]( const std::string& name ) ;
+    
 };
 
 // simple logging help
-inline void logTxtFunction(const char* file, const char* line, const char* expression, const bool verbose) {
+inline void logTxtFunction(const char* file, const int line, const char* expression, const bool verbose) {
     if (verbose) {
 	std::cout << file << ":" << line << " expression: " << expression << std::endl;
     }
 }
 
-#ifndef logTxT
+#ifdef logTxt
+#undef logTxt
+#endif
 //#define logTxt(x, b) logTxtFunction(__FILE__, __LINE__, x, b);
 #define logTxt(x, b) 
-#endif
